Enum graphics::draw_state::Blend [−][src]
pub enum Blend {
Alpha,
Add,
Lighter,
Multiply,
Invert,
}Expand description
The blend setting to use when drawing.
Using presets since some backends need one pipeline state object instance per blending technique.
Variants
Alpha blending (allows semi-transparent pixels).
new_dest_color = src_color * src_alpha + dest_color * (1 - src_alpha)
new_dest_alpha = src_alpha + dest_alphaAdditive blending.
new_dest_color = src_color + dest_color
new_dest_alpha = src_alpha + dest_alphaAdditive blending with alpha channel.
new_dest_color = src_color * src_alpha + dest_color
new_dest_alpha = dest_alphaMultiply color components.
new_dest_color = src_color * dest_color
new_dest_alpha = src_alpha * dest_alphaInvert colors when rendering a white shape.
new_dest_color = ref_color - src_color
new_dest_alpha = dest_alphaWhen combining two fragments, subtract the destination color from a constant color using the source color as weight. Has an invert effect with the constant color as base and source color controlling displacement from the base color. A white source color and a white value results in plain invert. The output alpha is same as destination alpha.