pub struct Grid {
pub cols: u32,
pub rows: u32,
pub units: Scalar,
}
Represents a flat grid with square cells.
The width and height of each grid cell.
Get a GridIterator for the grid
Get on-screen position of a grid cell
Get on-screen x position of a grid cell
Get on-screen y position of a grid cell
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.