Function graphics::math::inside_triangle [−][src]
Returns true if point is inside triangle.
This is done by computing a side number for each edge.
If the number is inside if it is on the same side for all edges.
Might break for very small triangles.