SourceRectangled

Trait SourceRectangled 

pub trait SourceRectangled {
    // Required methods
    fn src_rect(self, x: Scalar, y: Scalar, w: Scalar, h: Scalar) -> Self;
    fn src_rel(self, x: Scalar, y: Scalar) -> Self;
    fn src_flip_h(self) -> Self;
    fn src_flip_v(self) -> Self;
    fn src_flip_hv(self) -> Self;
}
Should be implemented by contexts that have source rectangle information.

Required Methods

fn src_rect(self, x: Scalar, y: Scalar, w: Scalar, h: Scalar) -> Self

Adds a source rectangle.

fn src_rel(self, x: Scalar, y: Scalar) -> Self

Moves to a relative source rectangle using the current source rectangle as tile.

fn src_flip_h(self) -> Self

Flips the source rectangle horizontally.

fn src_flip_v(self) -> Self

Flips the source rectangle vertically.

fn src_flip_hv(self) -> Self

Flips the source rectangle horizontally and vertically.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors