Struct graphics::character::Character[][src]

pub struct Character<'a, T: ImageSize> {
    pub offset: [Scalar; 2],
    pub advance_size: [Scalar; 2],
    pub atlas_offset: [Scalar; 2],
    pub atlas_size: [Scalar; 2],
    pub texture: &'a T,
}
Holds rendered character data.

Fields

offset: [Scalar; 2]

The offset of character.

advance_size: [Scalar; 2]

The advance size of character, including space.

atlas_offset: [Scalar; 2]

The offset of character within texture atlas.

atlas_size: [Scalar; 2]

The size of character within texture atlas.

texture: &'a T

The texture of the character.

Implementations

The left offset.

The top offset.

Gets width of character, including space to the next one.

Sets height of character, including space to the next one.