[−][src]Struct graphics::character::Character
Holds rendered character data.
Fields
offset: [Scalar; 2]The offset of character.
size: [Scalar; 2]The size of character, including space.
texture: &'a TThe texture of the character.
Methods
impl<'a, T: ImageSize> Character<'a, T>[src]
impl<'a, T: ImageSize> Character<'a, T>pub fn left(&self) -> Scalar | [src] |
The left offset.
pub fn top(&self) -> Scalar | [src] |
The top offset.
pub fn width(&self) -> Scalar | [src] |
Gets width of character, including space to the next one.
pub fn height(&self) -> Scalar | [src] |
Sets height of character, including space to the next one.