Struct graphics::circle_arc::CircleArc [−][src]
pub struct CircleArc {
pub color: Color,
pub radius: Radius,
pub start: Scalar,
pub end: Scalar,
pub resolution: Resolution,
}Expand description
A curved line
Fields
color: ColorThe arcs color
radius: RadiusThe radius of the arc (Thickness of the drawing, not the radius of the circle)
start: ScalarThe start of the arc in radians
end: ScalarThe end of the arc in radians
resolution: ResolutionThe resolution for the arc.
Implementations
Creates a new arc
Sets the radius of the arc (Thickness of the arc, not the radius of the circle it wraps)
Sets the resolution of the arcs smoothness.
Draws circle arc using default method.