[][src]Struct graphics::circle_arc::CircleArc

pub struct CircleArc {
    pub color: Color,
    pub radius: Radius,
    pub start: Scalar,
    pub end: Scalar,
    pub resolution: Resolution,
}

A curved line

Fields

color: Color

The arcs color

radius: Radius

The radius of the arc (Thickness of the drawing, not the radius of the circle)

start: Scalar

The start of the arc in radians

end: Scalar

The end of the arc in radians

resolution: Resolution

The resolution for the arc.

Methods

impl CircleArc
[src]

pub fn new(
    color: Color,
    radius: Radius,
    start: Scalar,
    end: Scalar
) -> CircleArc
[src]

Creates a new arc

pub fn color(self, value: Color) -> Self
[src]

Sets the arcs color.

pub fn radius(self, value: Radius) -> Self
[src]

Sets the radius of the arc (Thickness of the arc, not the radius of the circle it wraps)

pub fn start(self, value: Scalar) -> Self
[src]

Sets the start of the arc (in radians).

pub fn end(self, value: Scalar) -> Self
[src]

Sets the end of the arc (in radians).

pub fn resolution(self, value: Resolution) -> Self
[src]

Sets the resolution of the arcs smoothness.

pub fn draw<R: Into<Rectangle>, G>(
    &self,
    rectangle: R,
    draw_state: &DrawState,
    transform: Matrix2d,
    g: &mut G
) where
    G: Graphics
[src]

Draws circle arc using default method.

pub fn draw_tri<R: Into<Rectangle>, G>(
    &self,
    rectangle: R,
    draw_state: &DrawState,
    transform: Matrix2d,
    g: &mut G
) where
    G: Graphics
[src]

Draws circle arc using triangulation.