[][src]Struct graphics::context::Context

pub struct Context {
    pub viewport: Option<Viewport>,
    pub view: Matrix2d,
    pub transform: Matrix2d,
    pub draw_state: DrawState,
}

Drawing 2d context.

Fields

viewport: Option<Viewport>

Viewport information.

view: Matrix2d

View transformation.

transform: Matrix2d

Current transformation.

draw_state: DrawState

Current draw state settings.

Methods

impl Context[src]

pub fn new() -> Context[src]

Creates a new drawing context.

pub fn new_viewport(viewport: Viewport) -> Context[src]

Creates a new context with absolute transform in point coordinates.

This function assumes the default coordinate system being centered with x axis pointing to the right and y axis pointing up.

Returns a drawing context with origin in the upper left corner and x axis pointing to the right and y axis pointing down.

pub fn new_abs(w: Scalar, h: Scalar) -> Context[src]

Creates a new drawing context in absolute coordinates.

This function assumes the default coordinate system being centered with x axis pointing to the right and y axis pointing up.

Returns a drawing context with origin in the upper left corner and x axis pointing to the right and y axis pointing down.

pub fn view(self) -> Self[src]

Moves the current transform to the view coordinate system.

This is usually [0.0, 0.0] in the upper left corner with the x axis pointing to the right and the y axis pointing down.

pub fn reset(self) -> Self[src]

Moves the current transform to the default coordinate system.

This is usually [0.0, 0.0] in the center with the x axis pointing to the right and the y axis pointing up.

pub fn store_view(self) -> Self[src]

Stores the current transform as new view.

pub fn get_view_size(&self) -> Vec2d[src]

Computes the current view size.