[][src]Struct graphics::deform::DeformGrid

pub struct DeformGrid {
    pub cols: usize,
    pub rows: usize,
    pub rect: [Scalar; 4],
    pub vertices: Vec<Vec2d>,
    pub indices: Vec<usize>,
    pub texture_coords: Vec<[f32; 2]>,
    pub ps: Vec<[Scalar; 2]>,
    pub qs: Vec<[Scalar; 2]>,
    pub wis: Vec<Scalar>,
}

Represents a deformed grid.

Fields

cols: usize

The number of columns in the grid.

rows: usize

The number of rows in the grid.

rect: [Scalar; 4]

The grid undeformed, which is a plain rectangle.

vertices: Vec<Vec2d>

The vertices, deformed.

indices: Vec<usize>

The triangle indices.

texture_coords: Vec<[f32; 2]>

The texture coordinates.

ps: Vec<[Scalar; 2]>

Initial position of control points.

qs: Vec<[Scalar; 2]>

The current position of control points.

wis: Vec<Scalar>

A weight computation buffer, one for each control point.

Methods

impl DeformGrid
[src]

pub fn new(rect: Rectangle, cols: usize, rows: usize) -> DeformGrid
[src]

Creates a new DeformGrid.

pub fn set_current(&mut self, i: usize, pos: Vec2d)
[src]

Sets current control position.

pub fn set_original(&mut self, i: usize, pos: Vec2d)
[src]

Sets original control position.

pub fn reset_control_points(&mut self)
[src]

Removes all control points.

pub fn reset_vertices_and_texture_coords(&mut self)
[src]

Sets vertices and texture coords back to default.

pub fn hit(&self, pos: Vec2d) -> Option<Vec2d>
[src]

Finds original coordinate. If the deformed grid is overlapping itself, multiple hits might occur. Returns the first hit it finds.

pub fn draw_image<G>(
    &self,
    texture: &<G as Graphics>::Texture,
    draw_state: &DrawState,
    transform: Matrix2d,
    g: &mut G
) where
    G: Graphics
[src]

Draws deformed image using default method.

pub fn draw_image_tri<G>(
    &self,
    texture: &<G as Graphics>::Texture,
    draw_state: &DrawState,
    transform: Matrix2d,
    g: &mut G
) where
    G: Graphics
[src]

Draws deformed image using triangulation.

pub fn add_control_point(&mut self, pos: Vec2d)
[src]

Adds a control point, in original coordinates.

pub fn draw_vertical_lines<G>(
    &self,
    line: &Line,
    draw_state: &DrawState,
    transform: Matrix2d,
    g: &mut G
) where
    G: Graphics
[src]

Draw vertical grid lines.

pub fn draw_horizontal_lines<G>(
    &self,
    line: &Line,
    draw_state: &DrawState,
    transform: Matrix2d,
    g: &mut G
) where
    G: Graphics
[src]

Draw horizontal grid lines.

pub fn update(&mut self)
[src]

Updates the grid, by deforming the vertices.