pub enum Blend {
Alpha,
Add,
Multiply,
Invert,
}The blend setting to use when drawing.
Using presets since some backends need one pipeline state object instance
per blending technique.
Alpha blending (allows semi-transparent pixels).
new_dest_color = src_color * src_alpha + dest_color * (1 - src_alpha)
new_dest_alpha = src_alpha + dest_alpha
Additive blending.
new_dest_color = src_color + dest_color
new_dest_alpha = src_alpha + dest_alpha
Multiply color components.
new_dest_color = src_color * dest_color
new_dest_alpha = src_alpha * dest_alpha
Invert colors when rendering a white shape.
new_dest_color = ref_color - src_color
new_dest_alpha = dest_alpha
When combining two fragments, subtract the destination color from a constant color
using the source color as weight. Has an invert effect with the constant color
as base and source color controlling displacement from the base color.
A white source color and a white value results in plain invert.
The output alpha is same as destination alpha.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <= operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more
This method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static