Struct graphics::rectangle::Rectangle [−][src]
A filled rectangle
Fields
color: ColorThe rectangle color
shape: ShapeThe roundness of the rectangle
border: Option<Border>The border
Implementations
Creates a new rectangle with rounded corners.
Creates a new rectangle border.
Creates a new rectangle border with rounded corners.
Sets optional border.
Draws the rectangle by corners using the default method.
Draws the rectangle using the default method.
rectangle defines the rectangle’s location and dimensions,
draw_state draw state, draw_state::Default::default() can be used
as a default, transform is the transformation matrix, g is the
Graphics implementation, that is used to actually draw the rectangle.s