Stores viewport information.
Viewport in pixels.
[x, y, width height] where (x, y) is lower left corner.
The size of frame buffer in pixels.
The size of window in points.
Computes absolute transform for 2D graphics,
which uses a row major 2x3 matrix.
The origin is in the upper left corner of the viewport rectangle.
The x axis points to the right, and the y axis points down.
The units are in points (window coordinates).
It is assumed that the underlying coordinate system is normalized
with the origin in the center, such that (-1.0, 1.0) in the
underlying coordinate system corresponds to the
upper left corner of the viewport.
Formats the value using the given formatter. Read more
Performs copy-assignment from source. Read more
This method tests for self and other values to be equal, and is used by ==. Read more
This method tests for !=.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static